@@ -1,9 +1,9 @@
 #' DBIDriver class
 #'
 #' Base class for all DBMS drivers (e.g., RSQLite, MySQL, PostgreSQL).
-#' The virtual class \code{DBIDriver} defines the operations for creating
+#' The virtual class `DBIDriver` defines the operations for creating
 #' connections and defining data type mappings.  Actual driver classes, for
-#' instance \code{RPgSQL}, \code{RMySQL}, etc. implement these operations in a
+#' instance `RPgSQL`, `RMySQL`, etc. implement these operations in a
 #' DBMS-specific manner.
 #'
 #' @docType class
@@ -16,28 +16,32 @@ setClass("DBIDriver", contains = c("DBIObject", "VIRTUAL"))
 
 #' Load and unload database drivers
 #'
-#' \code{dbDriver} is a helper method used to create an new driver object
+#' @description
+#' These methods are deprecated, please consult the documentation of the
+#' individual backends for the construction of driver instances.
+#'
+#' `dbDriver()` is a helper method used to create an new driver object
 #' given the name of a database or the corresponding R package. It works
 #' through convention: all DBI-extending packages should provide an exported
-#' object with the same name as the package. \code{dbDriver} just looks for
+#' object with the same name as the package. `dbDriver()` just looks for
 #' this object in the right places: if you know what database you are connecting
 #' to, you should call the function directly.
 #'
-#' @section Side Effects:
+#' @details
 #' The client part of the database communication is
 #' initialized (typically dynamically loading C code, etc.) but note that
 #' connecting to the database engine itself needs to be done through calls to
-#' \code{dbConnect}.
+#' `dbConnect`.
 #'
 #' @param drvName character name of the driver to instantiate.
-#' @param drv an object that inherits from \code{DBIDriver} as created by
-#'   \code{dbDriver}.
-#' @param ... any other arguments are passed to the driver \code{drvName}.
-#' @return In the case of \code{dbDriver}, an driver object whose class extends
-#'   \code{DBIDriver}. This object may be used to create connections to the
+#' @param drv an object that inherits from `DBIDriver` as created by
+#'   `dbDriver`.
+#' @param ... any other arguments are passed to the driver `drvName`.
+#' @return In the case of `dbDriver`, an driver object whose class extends
+#'   `DBIDriver`. This object may be used to create connections to the
 #'   actual DBMS engine.
 #'
-#'   In the case of \code{dbUnloadDriver}, a logical indicating whether the
+#'   In the case of `dbUnloadDriver`, a logical indicating whether the
 #'   operation succeeded or not.
 #' @import methods
 #' @family DBIDriver generics
@@ -112,42 +116,40 @@ is_attached <- function(x) {
   x %in% loadedNamespaces()
 }
 
+#' @description
+#' `dbUnloadDriver()` is not implemented for modern backends.
 #' @rdname dbDriver
 #' @family DBIDriver generics
 #' @export
 setGeneric("dbUnloadDriver",
-  def = function(drv, ...) standardGeneric("dbUnloadDriver"),
-  valueClass = "logical"
+  def = function(drv, ...) standardGeneric("dbUnloadDriver")
 )
 
 #' Create a connection to a DBMS
 #'
-#' Connect to a DBMS going through the appropriate authorization procedure.
+#' Connect to a DBMS going through the appropriate authentication procedure.
 #' Some implementations may allow you to have multiple connections open, so you
 #' may invoke this function repeatedly assigning its output to different
-#' objects. The authorization mechanism is left unspecified, so check the
+#' objects.
+#' The authentication mechanism is left unspecified, so check the
 #' documentation of individual drivers for details.
 #'
-#' Each driver will define what other arguments are required, e.g.,
-#' \code{"dbname"} for the database name, \code{"username"}, and
-#' \code{"password"}.
+#' @inherit DBItest::spec_driver_connect return
+#' @inheritSection DBItest::spec_driver_connect Specification
 #'
-#' @param drv an object that inherits from \code{\linkS4class{DBIDriver}},
-#'   or an existing \code{\linkS4class{DBIConnection}}
+#' @param drv an object that inherits from [DBIDriver-class],
+#'   or an existing [DBIConnection-class]
 #'   object (in order to clone an existing connection).
-#' @param ... authorization arguments needed by the DBMS instance; these
-#'   typically include \code{user}, \code{password}, \code{dbname}, \code{host},
-#'   \code{port}, etc.  For details see the appropriate \code{DBIDriver}.
-#' @return An object that extends \code{\linkS4class{DBIConnection}} in a
-#'   database-specific manner. For instance \code{dbConnect(RMySQL::MySQL())} produces
-#'   an object of class \code{MySQLConnection}. This object is used to direct
-#'   commands to the database engine.
-#' @seealso \code{\link{dbDisconnect}} to disconnect from a database.
+#' @param ... authentication arguments needed by the DBMS instance; these
+#'   typically include `user`, `password`, `host`, `port`, `dbname`, etc.
+#'   For details see the appropriate `DBIDriver`.
+#' @seealso [dbDisconnect()] to disconnect from a database.
 #' @family DBIDriver generics
 #' @export
 #' @examples
-#' # SQLite only needs a path to the database. Other database drivers
-#' # will require more details (like username, password, host, port etc)
+#' # SQLite only needs a path to the database. (Here, ":memory:" is a special
+#' # path that creates an in-memory database.) Other database drivers
+#' # will require more details (like user, password, host, port, etc.)
 #' con <- dbConnect(RSQLite::SQLite(), ":memory:")
 #' con
 #'
@@ -165,7 +167,7 @@ setGeneric("dbConnect",
 #' containing a single element. If no connection are open, methods MUST
 #' return an empty list.
 #'
-#' @param drv A object inheriting from \code{\linkS4class{DBIDriver}}
+#' @param drv A object inheriting from [DBIDriver-class]
 #' @param ... Other arguments passed on to methods.
 #' @family DBIDriver generics
 #' @export
@@ -176,26 +178,32 @@ setGeneric("dbListConnections",
 
 #' Determine the SQL data type of an object
 #'
-#' This is a generic function. The default method determines the SQL type of an
+#' Returns an SQL string that describes the SQL data type to be used for an
+#' object.
+#' The default implementation of this generic determines the SQL type of an
 #' R object according to the SQL 92 specification, which may serve as a starting
-#' point for driver implementations. The default method also provides a method
+#' point for driver implementations. DBI also provides an implementation
 #' for data.frame which will return a character vector giving the type for each
 #' column in the dataframe.
 #'
 #' The data types supported by databases are different than the data types in R,
-#' but the mapping between the primitve types is straightforward:  Any of the
-#' many fixed and varying length character types are mapped to character
-#' vectors. Fixed-precision (non-IEEE) numbers are mapped into either numeric or
-#' integer vectors.
+#' but the mapping between the primitive types is straightforward:
+#' - Any of the many fixed and varying length character types are mapped to
+#'   character vectors
+#' - Fixed-precision (non-IEEE) numbers are mapped into either numeric or
+#'   integer vectors.
 #'
 #' Notice that many DBMS do not follow IEEE arithmetic, so there are potential
 #' problems with under/overflows and loss of precision.
 #'
+#' @inherit DBItest::spec_driver_data_type return
+#' @inheritSection DBItest::spec_driver_data_type Specification
+#' @inheritSection DBItest::spec_result_create_table_with_data_type Specification
+#'
 #' @inheritParams dbListConnections
-#' @param dbObj A object inheriting from \code{\linkS4class{DBIDriver}}
-#'   or \code{\linkS4class{DBIConnection}}
+#' @param dbObj A object inheriting from [DBIDriver-class]
+#'   or [DBIConnection-class]
 #' @param obj An R object whose SQL type we want to determine.
-#' @return A character string specifying the SQL data type for \code{obj}.
 #' @family DBIDriver generics
 #' @family DBIConnection generics
 #' @examples
